# (c) 2008 Canonical Ltd.
# Author: Martin Pitt <martin.pitt@ubuntu.com>
# License: GPL v2 or later

import re, os.path, logging
from glob import glob

from jockey.oslib import OSLib
from jockey.handlers import ModulePackageHandler, KernelModuleHandler

class B43Handler(ModulePackageHandler):
    '''Handler for Broadcom Wifi chipsets which use the b43 module and
    b43-fwcutter.'''

    def __init__(self, ui):
        ModulePackageHandler.__init__(self, ui, 'b43', 'b43-fwcutter',
            rationale=ui.string_nonfree_aux_firmware)

    def enabled(self):
        '''Return if the handler is enabled.
        
        'Enabled' means that the user agreed to use this driver if it is
        applicable.
        '''
        return KernelModuleHandler.enabled(self) and \
            len(glob('/lib/firmware/b43/*.fw')) > 0

    def used(self):
        '''Return if the handler is currently in use.'''

        return KernelModuleHandler.used(self) and \
            len(glob('/lib/firmware/b43/*.fw')) > 0

    def enable(self):
        '''Remove blacklist produced by BroadcomWLHandler.'''

        bl_file = '/etc/modprobe.d/blacklist-bcm43'
        if os.path.exists(bl_file):
            os.unlink(bl_file)
            OSLib.inst._load_module_blacklist()
            subprocess.call(['/usr/sbin/update-initramfs', '-u'])

        ModulePackageHandler.enable(self)
