# (c) 2008 Canonical Ltd.
# Author: Martin Pitt <martin.pitt@ubuntu.com>
# License: GPL v2 or later

import re, os.path, logging, subprocess, time
from glob import glob

from jockey.oslib import OSLib
from jockey.handlers import KernelModuleHandler

class BroadcomWLHandler(KernelModuleHandler):
    '''Handler for Broadcom Wifi chipsets which use the wl module.'''

    def __init__(self, ui):
        self.bl_file = os.path.join(os.path.dirname(
            OSLib.inst.module_blacklist_file), 'blacklist-bcm43')
        if KernelModuleHandler.module_loaded('b44'):
            raise SystemError, 'BroadcomWLHandler: would break b44, disabling myself'

        KernelModuleHandler.__init__(self, ui, 'wl',
            name=ui._('Broadcom STA wireless driver'))

    def enabled(self):
        km =  KernelModuleHandler.enabled(self)
        bcm = OSLib.inst.module_blacklisted('bcm43xx')
        b43 = OSLib.inst.module_blacklisted('b43')
        b43_legacy = OSLib.inst.module_blacklisted('b43_legacy')
        logging.debug('BroadcomWLHandler enabled(): kmod %s, bcm43xx: %s, b43: %s, b43_legacy: %s' % (
            km and 'enabled' or 'disabled',
            bcm and 'blacklisted' or 'enabled',
            b43 and 'blacklisted' or 'enabled',
            b43_legacy and 'blacklisted' or 'enabled'))

        return km and bcm and b43 and b43_legacy

    def used(self):
        '''Return if the handler is currently in use.'''

        return KernelModuleHandler.used(self) and self.enabled()

    def enable(self):
        '''Disable b43 drivers, so that wl can become active.'''

        if not os.path.exists(self.bl_file):
            f = open(self.bl_file, 'w')
            f.write('''blacklist bcm43xx
blacklist b43
blacklist b43_legacy
blacklist ssb
''')
            f.close()
            OSLib.inst._load_module_blacklist()
            self._update_initramfs()

        KernelModuleHandler.enable(self)
        OSLib.inst.ui_notify_reboot(self.ui)

    def disable(self):
        '''Unblacklist b43 drivers again, so that they trump wl.'''

        if os.path.exists(self.bl_file):
            os.unlink(self.bl_file)
            OSLib.inst._load_module_blacklist()
            self._update_initramfs()

        KernelModuleHandler.disable(self)
        OSLib.inst.ui_notify_reboot(self.ui)

    def _update_initramfs(self):
        self.ui.ui_download_start(self.name(), -1, self.ui._('Updating system'))
        self.ui.ui_idle()
        initramfs = subprocess.Popen(['/usr/sbin/update-initramfs', '-u'])
        while initramfs.poll() == None:
            self.ui.ui_download_progress(-1, -1)
            self.ui.ui_idle()
            time.sleep(0.2)
        self.ui.ui_download_finish()
        self.ui.ui_idle()
